@@ -1,9 +1,9 @@
 # SPDX-License-Identifier: GPL-3.0-only
-from gi.repository import Gtk
+from gi.repository import Adw, Gtk
 
 
 @Gtk.Template(resource_path="/org/gnome/World/Secrets/gtk/entry_page_tag.ui")
-class EntryPageTag(Gtk.FlowBoxChild):
+class EntryPageTag(Adw.Bin):
     __gtype_name__ = "EntryPageTag"
 
     _label = Gtk.Template.Child()
