@@ -8,10 +8,12 @@ from gettext import gettext as _
 from gi.repository import Adw, Gio, GLib, Gtk
 
 import gsecrets.config_manager
+from gsecrets import const
 from gsecrets.create_database import CreateDatabase
 from gsecrets.database_manager import DatabaseManager
 from gsecrets.err import QUARK, ErrorType
 from gsecrets.provider.providers import Providers
+from gsecrets.recent_manager import RecentManager
 from gsecrets.save_dialog import SaveDialog
 from gsecrets.settings_dialog import SettingsDialog
 from gsecrets.unlock_database import UnlockDatabase
@@ -87,9 +89,6 @@ class Window(Adw.ApplicationWindow):
         ):
             create_view.close_banner()
 
-    def close_notification(self, toast: Adw.Toast) -> None:
-        toast.dismiss()
-
     def assemble_window(self) -> None:
         window_size = gsecrets.config_manager.get_window_size()
         self.set_default_size(window_size[0], window_size[1])
@@ -120,8 +119,9 @@ class Window(Adw.ApplicationWindow):
             # simply load the last opened file
             uri = gsecrets.config_manager.get_last_opened_database()
             gfile: Gio.File = Gio.File.new_for_uri(uri)
-            recents = Gtk.RecentManager.get_default()
-            if gfile.query_exists() and recents.has_item(uri):
+            recents = RecentManager()
+            recent_uris = [f.get_uri() for f in recents]
+            if gfile.query_exists() and uri in recent_uris:
                 filepath = gfile.get_path()
                 logging.debug("Opening last opened database: %s", filepath)
                 self.start_database_opening_routine(filepath)
@@ -540,10 +540,26 @@ class Window(Adw.ApplicationWindow):
 
     def on_about_action(self, _action: Gio.Action, _param: GLib.Variant) -> None:
         """Invoked when we click "about" in the main menu."""
-        builder = Gtk.Builder.new_from_resource(
-            "/org/gnome/World/Secrets/about_dialog.ui",
+        about_dialog = Adw.AboutDialog.new_from_appdata(
+            f"/org/gnome/World/Secrets/{const.APP_ID}.metainfo.xml",
+            const.VERSION,
         )
-        about_dialog = builder.get_object("about_dialog")
+        about_dialog.set_designers(["Christopher Davis", "Tobias Bernard"])
+        about_dialog.set_developers(
+            [
+                "Falk Alexander Seidl <fseidl@gnome.org>",
+                "Uta Lemke",
+                "David Heidelberg",
+                "Jean Felder",
+                "Maximiliano Sandoval <msandova@gnome.org>",
+                "Sebastian Spaeth",
+                "Christopher Davis",
+                "Jan-Michael Brummer",
+            ],
+        )
+        about_dialog.set_copyright("© 2018-2024 Falk Alexander Seidl, et al.")
+        # TRANSLATORS Add your name to the translator credits list
+        about_dialog.set_translator_credits(_("translator-credits"))
         about_dialog.present(self)
 
     def on_settings_action(self, _action: Gio.Action, _param: GLib.Variant) -> None:
@@ -560,11 +576,12 @@ class Window(Adw.ApplicationWindow):
     @Gtk.Template.Callback()
     def on_back_button_pressed(
         self,
-        _gesture: Gtk.GestureClick,
+        gesture: Gtk.GestureClick,
         _n_press: int,
         _event_x: float,
         _event_y: float,
     ) -> None:
+        gesture.set_state(Gtk.EventSequenceState.CLAIMED)
         self.lookup_action("go_back").activate()
 
     @property
